FirecrackerStartup

Struct FirecrackerStartup 

pub struct FirecrackerStartup { /* private fields */ }
A structure for configuring the launch of FirecrackerVM. Helps to preconfigure and start the virtual machine.

Note: Firecracker must be installed globally.

Exemple:

let process = FirecrackerStartup::new()
    .set_api_socket("/tmp/some.socket")
    .download_rootfs(true)
    .download_kernel(true)
    .start().await.unwrap();

Implementations

Source

impl FirecrackerStartup

pub fn new() -> Self

Creates a new instance of FirecrackerStartup

pub fn set_api_socket<P: AsRef<Path>>(self, path: P) -> Self

Set the –api-sock startup argument with the path to the unix socket

Note: For the best documentation, please refer to here.

pub fn get_api_socket(&self) -> &PathBuf

Returns the –api-sock startup argument with the path to the unix socket

Note: For the best documentation, please refer to here.

pub fn download_kernel(self, flag: bool) -> Self

Flag to download the latest kernel version for microVM

pub fn download_rootfs(self, flag: bool) -> Self

Flag to download the ubuntu-22.04.ext4 for microVM

pub async fn start(self) -> Result<FirecrackerProcess>

Starts a VM with specified parameters Returns a structure for working with the Firecracker process